_internal/platform_interface/vonage_voice_platform_interface library

Classes

VonageVoicePlatform
Abstract platform interface for Vonage Voice session and device management.

Typedefs

OnDeviceTokenChanged = dynamic Function(String token)
Callback invoked when the native push token changes and needs re-registration.